"use client";
import Link from "next/link";
import {Button} from "../ui/button";
import {useEffect} from "react";
import {sendGAEvent} from "@next/third-parties/google";
import {navbarData} from "@/app/data/content";

interface Props {
  data: any;
}

export default function StatusContent({data}: Props) {
  if (data.success) {
    useEffect(() => {
      if (data.success) {
        sendGAEvent("event", "purchase", {
          transaction_id: data?.data.inv_id,
          value: data?.data.price,
          currency: "USD",
          items: [
            {
              item_name: "Villa Batu",
              price: data?.data.pernight,
              quantity: data?.data.quantity,
            },
          ],
        });
      }
    }, [data]);

    return (
      <div className="space-y-5 lg:w-[70%] w-full px-10 text-center lg:text-start">
        <h1 className="text-main">
          Thank you, your reservation has been confirmed.
        </h1>
        <p className="text-sm text-main">
          Please check your <span className="font-bold">Email</span> to see your
          Trip Details.
        </p>
        <Button
          asChild
          type="button"
          className="text-white bg-main hover:bg-main/80"
        >
          <Link href="/" className="font-bold tracking-wide m-0">
            Back to Home
          </Link>
        </Button>
      </div>
    );
  }

  return (
    <div className="px-5 lg:px-0 w-full lg:w-[70%] text-center space-y-4">
      <h1 className="text-main">{data.message}</h1>
      <p className="text-sm text-main">Please contact us below!</p>
      <div className="flex gap-2 items-center justify-center">
        <Button
          asChild
          type="button"
          className="text-white bg-main hover:bg-main/80"
        >
          <Link href="/" className="font-bold tracking-wide m-0">
            Back to Home
          </Link>
        </Button>
        <Button
          asChild
          type="button"
          className="text-white bg-main hover:bg-main/80"
        >
          <Link
            href={navbarData.waLink}
            target="_blank"
            className="font-bold tracking-wide m-0"
          >
            Contact Us
          </Link>
        </Button>
      </div>
    </div>
  );
}
